# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/websocket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import pubsub_pb2 as vemmio__client_dot_pubsub__pb2
from vemmio_client import reports_pb2 as vemmio__client_dot_reports__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvemmio_client/websocket.proto\x12\x08vemmiopb\x1a\x1avemmio_client/pubsub.proto\x1a\x1bvemmio_client/reports.proto\"\xa7\x01\n\x10WebsocketMessage\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\x04\x12)\n\x07request\x18\x02 \x01(\x0b\x32\x18.vemmiopb.CommandRequest\x12%\n\x05reply\x18\x03 \x01(\x0b\x32\x16.vemmiopb.CommandReply\x12/\n\x0egateway_report\x18\x04 \x01(\x0b\x32\x17.vemmiopb.GatewayReportB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.websocket_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _WEBSOCKETMESSAGE._serialized_start=101
  _WEBSOCKETMESSAGE._serialized_end=268
# @@protoc_insertion_point(module_scope)



from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
LOCK_SEC: LockMode
LOCK_UNKNOWN: LockMode
LOCK_UNSEC: LockMode
LOCK_UNSEC_IN: LockMode
LOCK_UNSEC_IN_TMOUT: LockMode
LOCK_UNSEC_OUT: LockMode
LOCK_UNSEC_OUT_TMOUT: LockMode
LOCK_UNSEC_TMOUT: LockMode

class LockReport(_message.Message):
    __slots__ = ["mode"]
    MODE_FIELD_NUMBER: _ClassVar[int]
    mode: LockMode
    def __init__(self, mode: _Optional[_Union[LockMode, str]] = ...) -> None: ...

class LockResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class LockSetRequest(_message.Message):
    __slots__ = ["metadata", "mode"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    mode: LockMode
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., mode: _Optional[_Union[LockMode, str]] = ...) -> None: ...

class LockMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/level.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/level.proto\x12\x08vemmiopb\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cvemmio_client/metadata.proto\":\n\x0cLevelRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x0f\n\rLevelResponse\"L\n\x0fLevelSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\r\n\x05value\x18\x02 \x01(\x05\"\x8f\x01\n\x10LevelStepRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12&\n\x03\x64im\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\'\n\x04\x64own\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"!\n\x10LevelGetResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1c\n\x0bLevelReport\x12\r\n\x05value\x18\x01 \x01(\x05\x32\xd9\x03\n\x05Level\x12>\n\x08LevelGet\x12\x16.vemmiopb.LevelRequest\x1a\x1a.vemmiopb.LevelGetResponse\x12\x42\n\x0cLevelGetStep\x12\x16.vemmiopb.LevelRequest\x1a\x1a.vemmiopb.LevelGetResponse\x12>\n\x08LevelSet\x12\x19.vemmiopb.LevelSetRequest\x1a\x17.vemmiopb.LevelResponse\x12>\n\x07LevelUp\x12\x1a.vemmiopb.LevelStepRequest\x1a\x17.vemmiopb.LevelResponse\x12@\n\tLevelDown\x12\x1a.vemmiopb.LevelStepRequest\x1a\x17.vemmiopb.LevelResponse\x12\x44\n\rLevelIncrease\x12\x1a.vemmiopb.LevelStepRequest\x1a\x17.vemmiopb.LevelResponse\x12\x44\n\rLevelDecrease\x12\x1a.vemmiopb.LevelStepRequest\x1a\x17.vemmiopb.LevelResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.level_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _LEVELREQUEST._serialized_start=101
  _LEVELREQUEST._serialized_end=159
  _LEVELRESPONSE._serialized_start=161
  _LEVELRESPONSE._serialized_end=176
  _LEVELSETREQUEST._serialized_start=178
  _LEVELSETREQUEST._serialized_end=254
  _LEVELSTEPREQUEST._serialized_start=257
  _LEVELSTEPREQUEST._serialized_end=400
  _LEVELGETRESPONSE._serialized_start=402
  _LEVELGETRESPONSE._serialized_end=435
  _LEVELREPORT._serialized_start=437
  _LEVELREPORT._serialized_end=465
  _LEVEL._serialized_start=468
  _LEVEL._serialized_end=941
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/door.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/door.proto\x12\x08vemmiopb\"0\n\nDoorReport\x12\"\n\x05\x65vent\x18\x01 \x01(\x0e\x32\x13.vemmiopb.DoorEvent*V\n\tDoorEvent\x12\x18\n\x14\x44OOR_EVENT_INTRUSION\x10\x00\x12\x19\n\x15\x44OOR_EVENT_HARD_KNOCK\x10\x01\x12\x14\n\x10\x44OOR_EVENT_KNOCK\x10\x02\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.door_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _DOOREVENT._serialized_start=88
  _DOOREVENT._serialized_end=174
  _DOORREPORT._serialized_start=38
  _DOORREPORT._serialized_end=86
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/accelerometer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!vemmio_client/accelerometer.proto\x12\x08vemmiopb\x1a\x19vemmio_client/units.proto\"m\n\x13\x41\x63\x63\x65lerometerReport\x12)\n\x04\x61xis\x18\x01 \x01(\x0e\x32\x1b.vemmiopb.AccelerometerAxis\x12\x1c\n\x04unit\x18\x02 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x03 \x01(\x01*(\n\x11\x41\x63\x63\x65lerometerAxis\x12\x05\n\x01X\x10\x00\x12\x05\n\x01Y\x10\x01\x12\x05\n\x01Z\x10\x02\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.accelerometer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ACCELEROMETERAXIS._serialized_start=185
  _ACCELEROMETERAXIS._serialized_end=225
  _ACCELEROMETERREPORT._serialized_start=74
  _ACCELEROMETERREPORT._serialized_end=183
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EmailMessage(_message.Message):
    __slots__ = ["message", "recipient", "subject"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    message: str
    recipient: str
    subject: str
    def __init__(self, recipient: _Optional[str] = ..., subject: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...

class PushMessage(_message.Message):
    __slots__ = ["badge", "message", "site_id", "site_name", "token"]
    BADGE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SITE_ID_FIELD_NUMBER: _ClassVar[int]
    SITE_NAME_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    badge: int
    message: str
    site_id: str
    site_name: str
    token: str
    def __init__(self, token: _Optional[str] = ..., message: _Optional[str] = ..., badge: _Optional[int] = ..., site_id: _Optional[str] = ..., site_name: _Optional[str] = ...) -> None: ...



from vemmio_client import devices_pb2 as _devices_pb2
from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ZigbeeExcludeRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ZigbeeMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ZigbeeMetadata, _Mapping]] = ...) -> None: ...

class ZigbeeExcludeResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZigbeeIncludeRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZigbeeIncludeResponse(_message.Message):
    __slots__ = ["devices"]
    DEVICES_FIELD_NUMBER: _ClassVar[int]
    devices: _containers.RepeatedCompositeFieldContainer[_devices_pb2.Device]
    def __init__(self, devices: _Optional[_Iterable[_Union[_devices_pb2.Device, _Mapping]]] = ...) -> None: ...

class ZigbeeNode(_message.Message):
    __slots__ = ["clusters", "endpoint", "eui64_addr", "ieee_addr"]
    CLUSTERS_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    EUI64_ADDR_FIELD_NUMBER: _ClassVar[int]
    IEEE_ADDR_FIELD_NUMBER: _ClassVar[int]
    clusters: _containers.RepeatedScalarFieldContainer[int]
    endpoint: int
    eui64_addr: str
    ieee_addr: int
    def __init__(self, ieee_addr: _Optional[int] = ..., eui64_addr: _Optional[str] = ..., endpoint: _Optional[int] = ..., clusters: _Optional[_Iterable[int]] = ...) -> None: ...

class ZigbeeNodesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ZigbeeNodesResponse(_message.Message):
    __slots__ = ["nodes"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[ZigbeeNode]
    def __init__(self, nodes: _Optional[_Iterable[_Union[ZigbeeNode, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/heartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvemmio_client/heartbeat.proto\x12\x08vemmiopb\"\x0e\n\x0cHeartbeatMsg2Q\n\tHeartbeat\x12\x44\n\x0eHeartbeatStart\x12\x16.vemmiopb.HeartbeatMsg\x1a\x16.vemmiopb.HeartbeatMsg(\x01\x30\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.heartbeat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _HEARTBEATMSG._serialized_start=43
  _HEARTBEATMSG._serialized_end=57
  _HEARTBEAT._serialized_start=59
  _HEARTBEAT._serialized_end=140
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/power_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n vemmio_client/power_source.proto\x12\x08vemmiopb\">\n\x11PowerSourceReport\x12)\n\x05\x65vent\x18\x01 \x01(\x0e\x32\x1a.vemmiopb.PowerSourceEvent*\xe8\x02\n\x10PowerSourceEvent\x12\t\n\x05\x43LEAR\x10\x00\x12\x11\n\rPOWER_APPLIED\x10\x01\x12\x11\n\rAC_POWER_LOST\x10\x02\x12\x15\n\x11\x41\x43_POWER_RESTORED\x10\x03\x12\x12\n\x0eSURGE_DETECTED\x10\x04\x12\x15\n\x11\x42ROWNOUT_DETECTED\x10\x05\x12\x19\n\x15OVER_CURRENT_DETECTED\x10\x06\x12\x19\n\x15OVER_VOLTAGE_DETECTED\x10\x07\x12\x16\n\x12OVER_LOAD_DETECTED\x10\x08\x12\x0e\n\nLOAD_ERROR\x10\t\x12\x18\n\x14\x42\x41TTERY_REPLACE_SOON\x10\n\x12\x17\n\x13\x42\x41TTERY_REPLACE_NOW\x10\x0b\x12\x14\n\x10\x42\x41TTERY_CHARGING\x10\x0c\x12\x13\n\x0f\x42\x41TTERY_CHARGED\x10\r\x12\x0f\n\x0b\x42\x41TTERY_LOW\x10\x0e\x12\x14\n\x10\x42\x41TTERY_CRITICAL\x10\x0f\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.power_source_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _POWERSOURCEEVENT._serialized_start=111
  _POWERSOURCEEVENT._serialized_end=471
  _POWERSOURCEREPORT._serialized_start=46
  _POWERSOURCEREPORT._serialized_end=108
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class InfoRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class InfoResponse(_message.Message):
    __slots__ = ["build_time", "common_name", "firmware_version", "git_commit", "version"]
    BUILD_TIME_FIELD_NUMBER: _ClassVar[int]
    COMMON_NAME_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    GIT_COMMIT_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    build_time: str
    common_name: str
    firmware_version: str
    git_commit: str
    version: str
    def __init__(self, common_name: _Optional[str] = ..., version: _Optional[str] = ..., git_commit: _Optional[str] = ..., build_time: _Optional[str] = ..., firmware_version: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/color.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/color.proto\x12\x08vemmiopb\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cvemmio_client/metadata.proto\"\x90\x01\n\x0f\x43olorSetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12$\n\x06values\x18\x02 \x03(\x0b\x32\x14.vemmiopb.ColorValue\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x0f\n\rColorResponse\"3\n\x0b\x43olorReport\x12$\n\x06values\x18\x01 \x03(\x0b\x32\x14.vemmiopb.ColorValue\"H\n\nColorValue\x12+\n\tcomponent\x18\x01 \x01(\x0e\x32\x18.vemmiopb.ColorComponent\x12\r\n\x05value\x18\x02 \x01(\x05*\x83\x01\n\x0e\x43olorComponent\x12\x15\n\x11\x43OLOR_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OLOR_WARM_WHITE\x10\x01\x12\x14\n\x10\x43OLOR_COLD_WHITE\x10\x02\x12\r\n\tCOLOR_RED\x10\x03\x12\x0f\n\x0b\x43OLOR_GREEN\x10\x04\x12\x0e\n\nCOLOR_BLUE\x10\x05\x32G\n\x05\x43olor\x12>\n\x08\x43olorSet\x12\x19.vemmiopb.ColorSetRequest\x1a\x17.vemmiopb.ColorResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.color_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _COLORCOMPONENT._serialized_start=393
  _COLORCOMPONENT._serialized_end=524
  _COLORSETREQUEST._serialized_start=102
  _COLORSETREQUEST._serialized_end=246
  _COLORRESPONSE._serialized_start=248
  _COLORRESPONSE._serialized_end=263
  _COLORREPORT._serialized_start=265
  _COLORREPORT._serialized_end=316
  _COLORVALUE._serialized_start=318
  _COLORVALUE._serialized_end=390
  _COLOR._serialized_start=526
  _COLOR._serialized_end=597
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LogsChunk(_message.Message):
    __slots__ = ["data"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class LogsRequest(_message.Message):
    __slots__ = ["count", "filter"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    count: int
    filter: str
    def __init__(self, filter: _Optional[str] = ..., count: _Optional[int] = ...) -> None: ...

class WalkNodesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class WalkNodesResponse(_message.Message):
    __slots__ = ["data"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/pubsub.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import addon_pb2 as vemmio__client_dot_addon__pb2
from vemmio_client import admin_pb2 as vemmio__client_dot_admin__pb2
from vemmio_client import battery_pb2 as vemmio__client_dot_battery__pb2
from vemmio_client import ble_pb2 as vemmio__client_dot_ble__pb2
from vemmio_client import carbon_monoxide_pb2 as vemmio__client_dot_carbon__monoxide__pb2
from vemmio_client import color_pb2 as vemmio__client_dot_color__pb2
from vemmio_client import configuration_pb2 as vemmio__client_dot_configuration__pb2
from vemmio_client import devices_pb2 as vemmio__client_dot_devices__pb2
from vemmio_client import firmware_pb2 as vemmio__client_dot_firmware__pb2
from vemmio_client import gate_pb2 as vemmio__client_dot_gate__pb2
from vemmio_client import gateway_pb2 as vemmio__client_dot_gateway__pb2
from vemmio_client import info_pb2 as vemmio__client_dot_info__pb2
from vemmio_client import level_pb2 as vemmio__client_dot_level__pb2
from vemmio_client import lock_pb2 as vemmio__client_dot_lock__pb2
from vemmio_client import messaging_pb2 as vemmio__client_dot_messaging__pb2
from vemmio_client import meter_pb2 as vemmio__client_dot_meter__pb2
from vemmio_client import remote_pb2 as vemmio__client_dot_remote__pb2
from vemmio_client import roller_shutter_pb2 as vemmio__client_dot_roller__shutter__pb2
from vemmio_client import siren_pb2 as vemmio__client_dot_siren__pb2
from vemmio_client import status_pb2 as vemmio__client_dot_status__pb2
from vemmio_client import structure_pb2 as vemmio__client_dot_structure__pb2
from vemmio_client import switch_pb2 as vemmio__client_dot_switch__pb2
from vemmio_client import temperature_pb2 as vemmio__client_dot_temperature__pb2
from vemmio_client import thermostat_pb2 as vemmio__client_dot_thermostat__pb2
from vemmio_client import ultraviolet_pb2 as vemmio__client_dot_ultraviolet__pb2
from vemmio_client import wifi_pb2 as vemmio__client_dot_wifi__pb2
from vemmio_client import zigbee_pb2 as vemmio__client_dot_zigbee__pb2
from vemmio_client import zwave_pb2 as vemmio__client_dot_zwave__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/pubsub.proto\x12\x08vemmiopb\x1a\x19vemmio_client/addon.proto\x1a\x19vemmio_client/admin.proto\x1a\x1bvemmio_client/battery.proto\x1a\x17vemmio_client/ble.proto\x1a#vemmio_client/carbon_monoxide.proto\x1a\x19vemmio_client/color.proto\x1a!vemmio_client/configuration.proto\x1a\x1bvemmio_client/devices.proto\x1a\x1cvemmio_client/firmware.proto\x1a\x18vemmio_client/gate.proto\x1a\x1bvemmio_client/gateway.proto\x1a\x18vemmio_client/info.proto\x1a\x19vemmio_client/level.proto\x1a\x18vemmio_client/lock.proto\x1a\x1dvemmio_client/messaging.proto\x1a\x19vemmio_client/meter.proto\x1a\x1avemmio_client/remote.proto\x1a\"vemmio_client/roller_shutter.proto\x1a\x19vemmio_client/siren.proto\x1a\x1avemmio_client/status.proto\x1a\x1dvemmio_client/structure.proto\x1a\x1avemmio_client/switch.proto\x1a\x1fvemmio_client/temperature.proto\x1a\x1evemmio_client/thermostat.proto\x1a\x1fvemmio_client/ultraviolet.proto\x1a\x18vemmio_client/wifi.proto\x1a\x1avemmio_client/zigbee.proto\x1a\x19vemmio_client/zwave.proto\"0\n\x13MetricsNotification\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x0c\"v\n\x14PresenceNotification\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x12\n\ngit_commit\x18\x03 \x01(\t\x12\x12\n\nbuild_time\x18\x04 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x05 \x01(\t\"\xba\x01\n\x0e\x43ommandRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.vemmiopb.CommandRequestType\x12*\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1c.vemmiopb.CommandRequestData\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12/\n\x07options\x18\x05 \x03(\x0e\x32\x1e.vemmiopb.CommandRequestOption\"\x9f\x01\n\x0c\x43ommandReply\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.vemmiopb.CommandReplyType\x12*\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1b.vemmiopb.CommandReplyError\x12(\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1a.vemmiopb.CommandReplyData\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\"$\n\x11\x43ommandReplyError\x12\x0f\n\x07message\x18\x01 \x01(\t\"m\n\x10MessagingRequest\x12\'\n\x05\x65mail\x18\x01 \x01(\x0b\x32\x16.vemmiopb.EmailMessageH\x00\x12%\n\x04push\x18\x02 \x01(\x0b\x32\x15.vemmiopb.PushMessageH\x00\x42\t\n\x07message\"\xe3#\n\x12\x43ommandRequestData\x12/\n\tAddonList\x18\x01 \x01(\x0b\x32\x1a.vemmiopb.AddonListRequestH\x00\x12\x41\n\x12\x41\x64\x64onAddThermostat\x18\x02 \x01(\x0b\x32#.vemmiopb.AddonAddThermostatRequestH\x00\x12/\n\tWalkNodes\x18\x65 \x01(\x0b\x32\x1a.vemmiopb.WalkNodesRequestH\x00\x12)\n\x08ReadLogs\x18\x66 \x01(\x0b\x32\x15.vemmiopb.LogsRequestH\x00\x12+\n\nFollowLogs\x18g \x01(\x0b\x32\x15.vemmiopb.LogsRequestH\x00\x12\x32\n\nBatteryGet\x18\x91\x03 \x01(\x0b\x32\x1b.vemmiopb.BatteryGetRequestH\x00\x12.\n\x08\x43olorSet\x18\xf5\x03 \x01(\x0b\x32\x19.vemmiopb.ColorSetRequestH\x00\x12@\n\x11\x43onfigurationList\x18\xd9\x04 \x01(\x0b\x32\".vemmiopb.ConfigurationListRequestH\x00\x12>\n\x10\x43onfigurationGet\x18\xda\x04 \x01(\x0b\x32!.vemmiopb.ConfigurationGetRequestH\x00\x12>\n\x10\x43onfigurationSet\x18\xdb\x04 \x01(\x0b\x32!.vemmiopb.ConfigurationSetRequestH\x00\x12@\n\x11ThermostatModeSet\x18\xbd\x05 \x01(\x0b\x32\".vemmiopb.ThermostatModeSetRequestH\x00\x12\x46\n\x14ThermostatModeSupGet\x18\xbe\x05 \x01(\x0b\x32%.vemmiopb.ThermostatModeSupGetRequestH\x00\x12H\n\x15ThermostatSetpointSet\x18\xbf\x05 \x01(\x0b\x32&.vemmiopb.ThermostatSetpointSetRequestH\x00\x12\x46\n\x14ThermostatFanModeSet\x18\xc0\x05 \x01(\x0b\x32%.vemmiopb.ThermostatFanModeSetRequestH\x00\x12\x34\n\x0b\x44\x65vicesList\x18\xa1\x06 \x01(\x0b\x32\x1c.vemmiopb.DevicesListRequestH\x00\x12\x32\n\x0e\x46irmwareUpload\x18\x85\x07 \x01(\x0b\x32\x17.vemmiopb.FirmwareChunkH\x00\x12<\n\x0f\x46irmwareUpgrade\x18\x86\x07 \x01(\x0b\x32 .vemmiopb.FirmwareUpgradeRequestH\x00\x12:\n\x0e\x46irmwareUpdate\x18\x87\x07 \x01(\x0b\x32\x1f.vemmiopb.FirmwareUpdateRequestH\x00\x12H\n\x15\x46irmwareLatestVersion\x18\x88\x07 \x01(\x0b\x32&.vemmiopb.FirmwareLatestVersionRequestH\x00\x12*\n\x06Reboot\x18\xe9\x07 \x01(\x0b\x32\x17.vemmiopb.RebootRequestH\x00\x12,\n\x07Restart\x18\xea\x07 \x01(\x0b\x32\x18.vemmiopb.RestartRequestH\x00\x12\x31\n\x0cStartSupport\x18\xeb\x07 \x01(\x0b\x32\x18.vemmiopb.SupportRequestH\x00\x12\x30\n\x0bStopSupport\x18\xec\x07 \x01(\x0b\x32\x18.vemmiopb.SupportRequestH\x00\x12&\n\x04Info\x18\xcd\x08 \x01(\x0b\x32\x15.vemmiopb.InfoRequestH\x00\x12+\n\x08LevelGet\x18\xb1\t \x01(\x0b\x32\x16.vemmiopb.LevelRequestH\x00\x12/\n\x0cLevelGetStep\x18\xb2\t \x01(\x0b\x32\x16.vemmiopb.LevelRequestH\x00\x12.\n\x08LevelSet\x18\xb3\t \x01(\x0b\x32\x19.vemmiopb.LevelSetRequestH\x00\x12.\n\x07LevelUp\x18\xb4\t \x01(\x0b\x32\x1a.vemmiopb.LevelStepRequestH\x00\x12\x30\n\tLevelDown\x18\xb5\t \x01(\x0b\x32\x1a.vemmiopb.LevelStepRequestH\x00\x12\x34\n\rLevelIncrease\x18\xb6\t \x01(\x0b\x32\x1a.vemmiopb.LevelStepRequestH\x00\x12\x34\n\rLevelDecrease\x18\xb7\t \x01(\x0b\x32\x1a.vemmiopb.LevelStepRequestH\x00\x12,\n\x07LockSet\x18\x95\n \x01(\x0b\x32\x18.vemmiopb.LockSetRequestH\x00\x12.\n\x08MeterGet\x18\xf9\n \x01(\x0b\x32\x19.vemmiopb.MeterGetRequestH\x00\x12\x32\n\nMeterReset\x18\xfa\n \x01(\x0b\x32\x1b.vemmiopb.MeterResetRequestH\x00\x12<\n\x11RollerShutterOpen\x18\xdd\x0b \x01(\x0b\x32\x1e.vemmiopb.RollerShutterRequestH\x00\x12=\n\x12RollerShutterClose\x18\xde\x0b \x01(\x0b\x32\x1e.vemmiopb.RollerShutterRequestH\x00\x12>\n\x10RollerShutterSet\x18\xdf\x0b \x01(\x0b\x32!.vemmiopb.RollerShutterSetRequestH\x00\x12\x38\n\rSirenGetTones\x18\xc1\x0c \x01(\x0b\x32\x1e.vemmiopb.SirenGetTonesRequestH\x00\x12\x38\n\rSirenPlayTone\x18\xc2\x0c \x01(\x0b\x32\x1e.vemmiopb.SirenPlayToneRequestH\x00\x12\x46\n\x14SirenPlayDefaultTone\x18\xc3\x0c \x01(\x0b\x32%.vemmiopb.SirenPlayDefaultToneRequestH\x00\x12\x44\n\x13SirenGetDefaultTone\x18\xc4\x0c \x01(\x0b\x32$.vemmiopb.SirenGetDefaultToneRequestH\x00\x12\x44\n\x13SirenSetDefaultTone\x18\xc5\x0c \x01(\x0b\x32$.vemmiopb.SirenSetDefaultToneRequestH\x00\x12:\n\x0eSirenGetVolume\x18\xc6\x0c \x01(\x0b\x32\x1f.vemmiopb.SirenGetVolumeRequestH\x00\x12:\n\x0eSirenSetVolume\x18\xc7\x0c \x01(\x0b\x32\x1f.vemmiopb.SirenSetVolumeRequestH\x00\x12,\n\x08SwitchOn\x18\xa5\r \x01(\x0b\x32\x17.vemmiopb.SwitchRequestH\x00\x12-\n\tSwitchOff\x18\xa6\r \x01(\x0b\x32\x17.vemmiopb.SwitchRequestH\x00\x12:\n\x0eTemperatureGet\x18\x89\x0e \x01(\x0b\x32\x1f.vemmiopb.TemperatureGetRequestH\x00\x12\x30\n\tWiFiQuery\x18\xed\x0e \x01(\x0b\x32\x1a.vemmiopb.WiFiQueryRequestH\x00\x12.\n\x08WiFiScan\x18\xee\x0e \x01(\x0b\x32\x19.vemmiopb.WiFiScanRequestH\x00\x12\x34\n\x0bWiFiConnect\x18\xef\x0e \x01(\x0b\x32\x1c.vemmiopb.WiFiConnectRequestH\x00\x12\x38\n\rZigbeeInclude\x18\xd1\x0f \x01(\x0b\x32\x1e.vemmiopb.ZigbeeIncludeRequestH\x00\x12\x38\n\rZigbeeExclude\x18\xd2\x0f \x01(\x0b\x32\x1e.vemmiopb.ZigbeeExcludeRequestH\x00\x12\x37\n\x0eZigbeeGetNodes\x18\xd3\x0f \x01(\x0b\x32\x1c.vemmiopb.ZigbeeNodesRequestH\x00\x12\x36\n\x0cZWaveInclude\x18\xb5\x10 \x01(\x0b\x32\x1d.vemmiopb.ZWaveIncludeRequestH\x00\x12\x36\n\x0cZWaveExclude\x18\xb6\x10 \x01(\x0b\x32\x1d.vemmiopb.ZWaveExcludeRequestH\x00\x12\x32\n\nZWaveAbort\x18\xb7\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveAbortRequestH\x00\x12\x36\n\x0eZWaveReadNodes\x18\xb8\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveNodesRequestH\x00\x12\x34\n\x0bZWaveUpdate\x18\xbb\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveUpdateRequestH\x00\x12<\n\x0fZWaveUpdateNode\x18\xbc\x10 \x01(\x0b\x32 .vemmiopb.ZWaveUpdateNodeRequestH\x00\x12\x32\n\nZWaveReset\x18\xbd\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveResetRequestH\x00\x12>\n\x10ZWaveListEntries\x18\xbe\x10 \x01(\x0b\x32!.vemmiopb.ZWaveListEntriesRequestH\x00\x12\x38\n\rZWaveAddEntry\x18\xbf\x10 \x01(\x0b\x32\x1e.vemmiopb.ZWaveAddEntryRequestH\x00\x12>\n\x10ZWaveRemoveEntry\x18\xc0\x10 \x01(\x0b\x32!.vemmiopb.ZWaveRemoveEntryRequestH\x00\x12J\n\x16ZWaveNotificationItems\x18\xc1\x10 \x01(\x0b\x32\'.vemmiopb.ZWaveNotificationItemsRequestH\x00\x12\x30\n\tZWaveTest\x18\xc2\x10 \x01(\x0b\x32\x1a.vemmiopb.ZWaveTestRequestH\x00\x12\x30\n\tZWaveHeal\x18\xc3\x10 \x01(\x0b\x32\x1a.vemmiopb.ZWaveHealRequestH\x00\x12\x42\n\x12ZWaveReplaceFailed\x18\xc4\x10 \x01(\x0b\x32#.vemmiopb.ZWaveReplaceFailedRequestH\x00\x12@\n\x11ZWaveRemoveFailed\x18\xc5\x10 \x01(\x0b\x32\".vemmiopb.ZWaveRemoveFailedRequestH\x00\x12>\n\x10ZWaveHealthCheck\x18\xc6\x10 \x01(\x0b\x32!.vemmiopb.ZWaveHealthCheckRequestH\x00\x12\x34\n\rZWaveReadNode\x18\xc7\x10 \x01(\x0b\x32\x1a.vemmiopb.ZWaveNodeRequestH\x00\x12@\n\x11\x43\x61rbonMonoxideGet\x18\x99\x11 \x01(\x0b\x32\".vemmiopb.CarbonMonoxideGetRequestH\x00\x12:\n\x11\x45nableAdvertising\x18\xfd\x11 \x01(\x0b\x32\x1c.vemmiopb.AdvertisingRequestH\x00\x12;\n\x12\x44isableAdvertising\x18\xfe\x11 \x01(\x0b\x32\x1c.vemmiopb.AdvertisingRequestH\x00\x12:\n\x0eUltravioletGet\x18\xe1\x12 \x01(\x0b\x32\x1f.vemmiopb.UltravioletGetRequestH\x00\x12)\n\x05KeyUp\x18\xc5\x13 \x01(\x0b\x32\x17.vemmiopb.RemoteRequestH\x00\x12+\n\x07KeyDown\x18\xc6\x13 \x01(\x0b\x32\x17.vemmiopb.RemoteRequestH\x00\x12*\n\x08GateOpen\x18\xa9\x14 \x01(\x0b\x32\x15.vemmiopb.GateRequestH\x00\x12+\n\tGateClose\x18\xaa\x14 \x01(\x0b\x32\x15.vemmiopb.GateRequestH\x00\x12+\n\tGateCycle\x18\xab\x14 \x01(\x0b\x32\x15.vemmiopb.GateRequestH\x00\x12\x34\n\x0bStatusCheck\x18\x8d\x15 \x01(\x0b\x32\x1c.vemmiopb.StatusCheckRequestH\x00\x12\x33\n\x0cGetStructure\x18\xf1\x15 \x01(\x0b\x32\x1a.vemmiopb.StructureRequestH\x00\x42\x06\n\x04\x64\x61ta\"\xe5#\n\x10\x43ommandReplyData\x12\x30\n\tAddonList\x18\x01 \x01(\x0b\x32\x1b.vemmiopb.AddonListResponseH\x00\x12\x38\n\x12\x41\x64\x64onAddThermostat\x18\x02 \x01(\x0b\x32\x1a.vemmiopb.AddonAddResponseH\x00\x12\x30\n\tWalkNodes\x18\x65 \x01(\x0b\x32\x1b.vemmiopb.WalkNodesResponseH\x00\x12\'\n\x08ReadLogs\x18\x66 \x01(\x0b\x32\x13.vemmiopb.LogsChunkH\x00\x12)\n\nFollowLogs\x18g \x01(\x0b\x32\x13.vemmiopb.LogsChunkH\x00\x12\x33\n\nBatteryGet\x18\x91\x03 \x01(\x0b\x32\x1c.vemmiopb.BatteryGetResponseH\x00\x12,\n\x08\x43olorSet\x18\xf5\x03 \x01(\x0b\x32\x17.vemmiopb.ColorResponseH\x00\x12\x41\n\x11\x43onfigurationList\x18\xd9\x04 \x01(\x0b\x32#.vemmiopb.ConfigurationListResponseH\x00\x12?\n\x10\x43onfigurationGet\x18\xda\x04 \x01(\x0b\x32\".vemmiopb.ConfigurationGetResponseH\x00\x12?\n\x10\x43onfigurationSet\x18\xdb\x04 \x01(\x0b\x32\".vemmiopb.ConfigurationSetResponseH\x00\x12:\n\x11ThermostatModeSet\x18\xbd\x05 \x01(\x0b\x32\x1c.vemmiopb.ThermostatResponseH\x00\x12G\n\x14ThermostatModeSupGet\x18\xbe\x05 \x01(\x0b\x32&.vemmiopb.ThermostatModeSupGetResponseH\x00\x12>\n\x15ThermostatSetpointSet\x18\xbf\x05 \x01(\x0b\x32\x1c.vemmiopb.ThermostatResponseH\x00\x12=\n\x14ThermostatFanModeSet\x18\xc0\x05 \x01(\x0b\x32\x1c.vemmiopb.ThermostatResponseH\x00\x12\x35\n\x0b\x44\x65vicesList\x18\xa1\x06 \x01(\x0b\x32\x1d.vemmiopb.DevicesListResponseH\x00\x12\x35\n\x0e\x46irmwareUpload\x18\x85\x07 \x01(\x0b\x32\x1a.vemmiopb.FirmwareChunkAckH\x00\x12\x38\n\x0f\x46irmwareUpgrade\x18\x86\x07 \x01(\x0b\x32\x1c.vemmiopb.FirmwareUpgradeAckH\x00\x12;\n\x0e\x46irmwareUpdate\x18\x87\x07 \x01(\x0b\x32 .vemmiopb.FirmwareUpdateResponseH\x00\x12I\n\x15\x46irmwareLatestVersion\x18\x88\x07 \x01(\x0b\x32\'.vemmiopb.FirmwareLatestVersionResponseH\x00\x12+\n\x06Reboot\x18\xe9\x07 \x01(\x0b\x32\x18.vemmiopb.RebootResponseH\x00\x12-\n\x07Restart\x18\xea\x07 \x01(\x0b\x32\x19.vemmiopb.RestartResponseH\x00\x12\x32\n\x0cStartSupport\x18\xeb\x07 \x01(\x0b\x32\x19.vemmiopb.SupportResponseH\x00\x12\x31\n\x0bStopSupport\x18\xec\x07 \x01(\x0b\x32\x19.vemmiopb.SupportResponseH\x00\x12\'\n\x04Info\x18\xcd\x08 \x01(\x0b\x32\x16.vemmiopb.InfoResponseH\x00\x12/\n\x08LevelGet\x18\xb1\t \x01(\x0b\x32\x1a.vemmiopb.LevelGetResponseH\x00\x12\x33\n\x0cLevelGetStep\x18\xb2\t \x01(\x0b\x32\x1a.vemmiopb.LevelGetResponseH\x00\x12,\n\x08LevelSet\x18\xb3\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12+\n\x07LevelUp\x18\xb4\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12-\n\tLevelDown\x18\xb5\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12\x31\n\rLevelIncrease\x18\xb6\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12\x31\n\rLevelDecrease\x18\xb7\t \x01(\x0b\x32\x17.vemmiopb.LevelResponseH\x00\x12*\n\x07LockSet\x18\x95\n \x01(\x0b\x32\x16.vemmiopb.LockResponseH\x00\x12/\n\x08MeterGet\x18\xf9\n \x01(\x0b\x32\x1a.vemmiopb.MeterGetResponseH\x00\x12\x33\n\nMeterReset\x18\xfa\n \x01(\x0b\x32\x1c.vemmiopb.MeterResetResponseH\x00\x12=\n\x11RollerShutterOpen\x18\xdd\x0b \x01(\x0b\x32\x1f.vemmiopb.RollerShutterResponseH\x00\x12>\n\x12RollerShutterClose\x18\xde\x0b \x01(\x0b\x32\x1f.vemmiopb.RollerShutterResponseH\x00\x12<\n\x10RollerShutterSet\x18\xdf\x0b \x01(\x0b\x32\x1f.vemmiopb.RollerShutterResponseH\x00\x12\x39\n\rSirenGetTones\x18\xc1\x0c \x01(\x0b\x32\x1f.vemmiopb.SirenGetTonesResponseH\x00\x12\x39\n\rSirenPlayTone\x18\xc2\x0c \x01(\x0b\x32\x1f.vemmiopb.SirenPlayToneResponseH\x00\x12G\n\x14SirenPlayDefaultTone\x18\xc3\x0c \x01(\x0b\x32&.vemmiopb.SirenPlayDefaultToneResponseH\x00\x12\x45\n\x13SirenGetDefaultTone\x18\xc4\x0c \x01(\x0b\x32%.vemmiopb.SirenGetDefaultToneResponseH\x00\x12\x45\n\x13SirenSetDefaultTone\x18\xc5\x0c \x01(\x0b\x32%.vemmiopb.SirenSetDefaultToneResponseH\x00\x12;\n\x0eSirenGetVolume\x18\xc6\x0c \x01(\x0b\x32 .vemmiopb.SirenGetVolumeResponseH\x00\x12;\n\x0eSirenSetVolume\x18\xc7\x0c \x01(\x0b\x32 .vemmiopb.SirenSetVolumeResponseH\x00\x12-\n\x08SwitchOn\x18\xa5\r \x01(\x0b\x32\x18.vemmiopb.SwitchResponseH\x00\x12.\n\tSwitchOff\x18\xa6\r \x01(\x0b\x32\x18.vemmiopb.SwitchResponseH\x00\x12;\n\x0eTemperatureGet\x18\x89\x0e \x01(\x0b\x32 .vemmiopb.TemperatureGetResponseH\x00\x12\x31\n\tWiFiQuery\x18\xed\x0e \x01(\x0b\x32\x1b.vemmiopb.WiFiQueryResponseH\x00\x12/\n\x08WiFiScan\x18\xee\x0e \x01(\x0b\x32\x1a.vemmiopb.WiFiScanResponseH\x00\x12\x35\n\x0bWiFiConnect\x18\xef\x0e \x01(\x0b\x32\x1d.vemmiopb.WiFiConnectResponseH\x00\x12\x39\n\rZigbeeInclude\x18\xd1\x0f \x01(\x0b\x32\x1f.vemmiopb.ZigbeeIncludeResponseH\x00\x12\x39\n\rZigbeeExclude\x18\xd2\x0f \x01(\x0b\x32\x1f.vemmiopb.ZigbeeExcludeResponseH\x00\x12\x38\n\x0eZigbeeGetNodes\x18\xd3\x0f \x01(\x0b\x32\x1d.vemmiopb.ZigbeeNodesResponseH\x00\x12\x35\n\x0cZWaveInclude\x18\xb5\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveIncludeStatusH\x00\x12\x35\n\x0cZWaveExclude\x18\xb6\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveExcludeStatusH\x00\x12\x33\n\nZWaveAbort\x18\xb7\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveAbortResponseH\x00\x12\x37\n\x0eZWaveReadNodes\x18\xb8\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveNodesResponseH\x00\x12\x33\n\x0bZWaveUpdate\x18\xbb\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveUpdateStatusH\x00\x12=\n\x0fZWaveUpdateNode\x18\xbc\x10 \x01(\x0b\x32!.vemmiopb.ZWaveUpdateNodeResponseH\x00\x12\x33\n\nZWaveReset\x18\xbd\x10 \x01(\x0b\x32\x1c.vemmiopb.ZWaveResetResponseH\x00\x12?\n\x10ZWaveListEntries\x18\xbe\x10 \x01(\x0b\x32\".vemmiopb.ZWaveListEntriesResponseH\x00\x12\x39\n\rZWaveAddEntry\x18\xbf\x10 \x01(\x0b\x32\x1f.vemmiopb.ZWaveAddEntryResponseH\x00\x12?\n\x10ZWaveRemoveEntry\x18\xc0\x10 \x01(\x0b\x32\".vemmiopb.ZWaveRemoveEntryResponseH\x00\x12K\n\x16ZWaveNotificationItems\x18\xc1\x10 \x01(\x0b\x32(.vemmiopb.ZWaveNotificationItemsResponseH\x00\x12\x31\n\tZWaveTest\x18\xc2\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveTestResponseH\x00\x12\x31\n\tZWaveHeal\x18\xc3\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveHealResponseH\x00\x12\x43\n\x12ZWaveReplaceFailed\x18\xc4\x10 \x01(\x0b\x32$.vemmiopb.ZWaveReplaceFailedResponseH\x00\x12\x41\n\x11ZWaveRemoveFailed\x18\xc5\x10 \x01(\x0b\x32#.vemmiopb.ZWaveRemoveFailedResponseH\x00\x12=\n\x10ZWaveHealthCheck\x18\xc6\x10 \x01(\x0b\x32 .vemmiopb.ZWaveHealthCheckStatusH\x00\x12\x35\n\rZWaveReadNode\x18\xc7\x10 \x01(\x0b\x32\x1b.vemmiopb.ZWaveNodeResponseH\x00\x12\x41\n\x11\x43\x61rbonMonoxideGet\x18\x99\x11 \x01(\x0b\x32#.vemmiopb.CarbonMonoxideGetResponseH\x00\x12;\n\x11\x45nableAdvertising\x18\xfd\x11 \x01(\x0b\x32\x1d.vemmiopb.AdvertisingResponseH\x00\x12<\n\x12\x44isableAdvertising\x18\xfe\x11 \x01(\x0b\x32\x1d.vemmiopb.AdvertisingResponseH\x00\x12;\n\x0eUltravioletGet\x18\xe1\x12 \x01(\x0b\x32 .vemmiopb.UltravioletGetResponseH\x00\x12*\n\x05KeyUp\x18\xc5\x13 \x01(\x0b\x32\x18.vemmiopb.RemoteResponseH\x00\x12,\n\x07KeyDown\x18\xc6\x13 \x01(\x0b\x32\x18.vemmiopb.RemoteResponseH\x00\x12+\n\x08GateOpen\x18\xa9\x14 \x01(\x0b\x32\x16.vemmiopb.GateResponseH\x00\x12,\n\tGateClose\x18\xaa\x14 \x01(\x0b\x32\x16.vemmiopb.GateResponseH\x00\x12,\n\tGateCycle\x18\xab\x14 \x01(\x0b\x32\x16.vemmiopb.GateResponseH\x00\x12\x35\n\x0bStatusCheck\x18\x8d\x15 \x01(\x0b\x32\x1d.vemmiopb.StatusCheckResponseH\x00\x12\x34\n\x0cGetStructure\x18\xf1\x15 \x01(\x0b\x32\x1b.vemmiopb.StructureResponseH\x00\x42\x06\n\x04\x64\x61ta*_\n\x12\x43ommandRequestType\x12\x1c\n\x18REQUEST_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11REQUEST_TYPE_DATA\x10\x01\x12\x14\n\x10REQUEST_TYPE_EOF\x10\x02*o\n\x14\x43ommandRequestOption\x12\x1e\n\x1aREQUEST_OPTION_UNSPECIFIED\x10\x00\x12\x18\n\x14REQUEST_OPTION_NOACK\x10\x01\x12\x1d\n\x19REQUEST_OPTION_NORESPONSE\x10\x02*\x81\x01\n\x10\x43ommandReplyType\x12\x1a\n\x16REPLY_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eREPLY_TYPE_ACK\x10\x01\x12\x14\n\x10REPLY_TYPE_ERROR\x10\x02\x12\x12\n\x0eREPLY_TYPE_EOF\x10\x03\x12\x13\n\x0fREPLY_TYPE_DATA\x10\x04\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.pubsub_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _COMMANDREQUESTTYPE._serialized_start=10691
  _COMMANDREQUESTTYPE._serialized_end=10786
  _COMMANDREQUESTOPTION._serialized_start=10788
  _COMMANDREQUESTOPTION._serialized_end=10899
  _COMMANDREPLYTYPE._serialized_start=10902
  _COMMANDREPLYTYPE._serialized_end=11031
  _METRICSNOTIFICATION._serialized_start=855
  _METRICSNOTIFICATION._serialized_end=903
  _PRESENCENOTIFICATION._serialized_start=905
  _PRESENCENOTIFICATION._serialized_end=1023
  _COMMANDREQUEST._serialized_start=1026
  _COMMANDREQUEST._serialized_end=1212
  _COMMANDREPLY._serialized_start=1215
  _COMMANDREPLY._serialized_end=1374
  _COMMANDREPLYERROR._serialized_start=1376
  _COMMANDREPLYERROR._serialized_end=1412
  _MESSAGINGREQUEST._serialized_start=1414
  _MESSAGINGREQUEST._serialized_end=1523
  _COMMANDREQUESTDATA._serialized_start=1526
  _COMMANDREQUESTDATA._serialized_end=6105
  _COMMANDREPLYDATA._serialized_start=6108
  _COMMANDREPLYDATA._serialized_end=10689
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/bsensor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvemmio_client/bsensor.proto\x12\x08vemmiopb\":\n\x0fOpenCloseReport\x12\'\n\x05state\x18\x01 \x01(\x0e\x32\x18.vemmiopb.OpenCloseState\"\\\n\x0cMotionReport\x12+\n\x05state\x18\x01 \x01(\x0e\x32\x1c.vemmiopb.MotionReport.State\"\x1f\n\x05State\x12\x08\n\x04IDLE\x10\x00\x12\x0c\n\x08\x44\x45TECTED\x10\x01*H\n\x0eOpenCloseState\x12\x19\n\x15OPEN_CLOSE_STATE_OPEN\x10\x00\x12\x1b\n\x17OPEN_CLOSE_STATE_CLOSED\x10\x01*M\n\x11\x42inarySensorState\x12\x16\n\x12\x42SENSOR_STATE_IDLE\x10\x00\x12 \n\x1c\x42SENSOR_STATE_EVENT_DETECTED\x10\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.bsensor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _OPENCLOSESTATE._serialized_start=195
  _OPENCLOSESTATE._serialized_end=267
  _BINARYSENSORSTATE._serialized_start=269
  _BINARYSENSORSTATE._serialized_end=346
  _OPENCLOSEREPORT._serialized_start=41
  _OPENCLOSEREPORT._serialized_end=99
  _MOTIONREPORT._serialized_start=101
  _MOTIONREPORT._serialized_end=193
  _MOTIONREPORT_STATE._serialized_start=162
  _MOTIONREPORT_STATE._serialized_end=193
# @@protoc_insertion_point(module_scope)



from vemmio_client import pubsub_pb2 as _pubsub_pb2
from vemmio_client import reports_pb2 as _reports_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WebsocketMessage(_message.Message):
    __slots__ = ["frame_id", "gateway_report", "reply", "request"]
    FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    GATEWAY_REPORT_FIELD_NUMBER: _ClassVar[int]
    REPLY_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    frame_id: int
    gateway_report: _reports_pb2.GatewayReport
    reply: _pubsub_pb2.CommandReply
    request: _pubsub_pb2.CommandRequest
    def __init__(self, frame_id: _Optional[int] = ..., request: _Optional[_Union[_pubsub_pb2.CommandRequest, _Mapping]] = ..., reply: _Optional[_Union[_pubsub_pb2.CommandReply, _Mapping]] = ..., gateway_report: _Optional[_Union[_reports_pb2.GatewayReport, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/switch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/switch.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\";\n\rSwitchRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x10\n\x0eSwitchResponse\"4\n\x0cSwitchReport\x12$\n\x05value\x18\x01 \x01(\x0e\x32\x15.vemmiopb.SwitchValue*@\n\x0bSwitchValue\x12\x12\n\x0eSWITCH_UNKNOWN\x10\x00\x12\r\n\tSWITCH_ON\x10\x01\x12\x0e\n\nSWITCH_OFF\x10\x02\x32\x87\x01\n\x06Switch\x12=\n\x08SwitchOn\x12\x17.vemmiopb.SwitchRequest\x1a\x18.vemmiopb.SwitchResponse\x12>\n\tSwitchOff\x12\x17.vemmiopb.SwitchRequest\x1a\x18.vemmiopb.SwitchResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.switch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _SWITCHVALUE._serialized_start=203
  _SWITCHVALUE._serialized_end=267
  _SWITCHREQUEST._serialized_start=70
  _SWITCHREQUEST._serialized_end=129
  _SWITCHRESPONSE._serialized_start=131
  _SWITCHRESPONSE._serialized_end=147
  _SWITCHREPORT._serialized_start=149
  _SWITCHREPORT._serialized_end=201
  _SWITCH._serialized_start=270
  _SWITCH._serialized_end=405
# @@protoc_insertion_point(module_scope)



from vemmio_client import pubsub_pb2 as _pubsub_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MQTTCommandRequest(_message.Message):
    __slots__ = ["request", "response_topic"]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_TOPIC_FIELD_NUMBER: _ClassVar[int]
    request: _pubsub_pb2.CommandRequest
    response_topic: str
    def __init__(self, request: _Optional[_Union[_pubsub_pb2.CommandRequest, _Mapping]] = ..., response_topic: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/temperature.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvemmio_client/temperature.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/units.proto\"T\n\x15TemperatureGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x0f\n\x07refresh\x18\x02 \x01(\x08\"E\n\x16TemperatureGetResponse\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"@\n\x11TemperatureReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\x32\x62\n\x0bTemperature\x12S\n\x0eTemperatureGet\x12\x1f.vemmiopb.TemperatureGetRequest\x1a .vemmiopb.TemperatureGetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.temperature_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _TEMPERATUREGETREQUEST._serialized_start=102
  _TEMPERATUREGETREQUEST._serialized_end=186
  _TEMPERATUREGETRESPONSE._serialized_start=188
  _TEMPERATUREGETRESPONSE._serialized_end=257
  _TEMPERATUREREPORT._serialized_start=259
  _TEMPERATUREREPORT._serialized_end=323
  _TEMPERATURE._serialized_start=325
  _TEMPERATURE._serialized_end=423
# @@protoc_insertion_point(module_scope)



from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RemoteReport(_message.Message):
    __slots__ = ["count", "event", "key"]
    class Event(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    COUNT_FIELD_NUMBER: _ClassVar[int]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    HELD_DOWN: RemoteReport.Event
    KEY_FIELD_NUMBER: _ClassVar[int]
    PRESSED: RemoteReport.Event
    RELEASED: RemoteReport.Event
    UNKNOWN: RemoteReport.Event
    count: int
    event: RemoteReport.Event
    key: int
    def __init__(self, event: _Optional[_Union[RemoteReport.Event, str]] = ..., count: _Optional[int] = ..., key: _Optional[int] = ...) -> None: ...

class RemoteRequest(_message.Message):
    __slots__ = ["key", "metadata"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    key: int
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., key: _Optional[int] = ...) -> None: ...

class RemoteResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/remote.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/remote.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"H\n\rRemoteRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x0b\n\x03key\x18\x02 \x01(\x05\"\x10\n\x0eRemoteResponse\"\x97\x01\n\x0cRemoteReport\x12+\n\x05\x65vent\x18\x01 \x01(\x0e\x32\x1c.vemmiopb.RemoteReport.Event\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x0b\n\x03key\x18\x03 \x01(\x05\">\n\x05\x45vent\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PRESSED\x10\x01\x12\x0c\n\x08RELEASED\x10\x02\x12\r\n\tHELD_DOWN\x10\x03\x32\x89\x01\n\rRemoteService\x12:\n\x05KeyUp\x12\x17.vemmiopb.RemoteRequest\x1a\x18.vemmiopb.RemoteResponse\x12<\n\x07KeyDown\x12\x17.vemmiopb.RemoteRequest\x1a\x18.vemmiopb.RemoteResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.remote_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _REMOTEREQUEST._serialized_start=70
  _REMOTEREQUEST._serialized_end=142
  _REMOTERESPONSE._serialized_start=144
  _REMOTERESPONSE._serialized_end=160
  _REMOTEREPORT._serialized_start=163
  _REMOTEREPORT._serialized_end=314
  _REMOTEREPORT_EVENT._serialized_start=252
  _REMOTEREPORT_EVENT._serialized_end=314
  _REMOTESERVICE._serialized_start=317
  _REMOTESERVICE._serialized_end=454
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/ble.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17vemmio_client/ble.proto\x12\x08vemmiopb\"\x14\n\x12\x41\x64vertisingRequest\"\x15\n\x13\x41\x64vertisingResponse2\xb1\x01\n\nBLEService\x12P\n\x11\x45nableAdvertising\x12\x1c.vemmiopb.AdvertisingRequest\x1a\x1d.vemmiopb.AdvertisingResponse\x12Q\n\x12\x44isableAdvertising\x12\x1c.vemmiopb.AdvertisingRequest\x1a\x1d.vemmiopb.AdvertisingResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.ble_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ADVERTISINGREQUEST._serialized_start=37
  _ADVERTISINGREQUEST._serialized_end=57
  _ADVERTISINGRESPONSE._serialized_start=59
  _ADVERTISINGRESPONSE._serialized_end=80
  _BLESERVICE._serialized_start=83
  _BLESERVICE._serialized_end=260
# @@protoc_insertion_point(module_scope)



from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

CONFIGURATION_VALUE_TYPE_BOOL: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_FLOAT32: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_FLOAT64: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_INT16: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_INT32: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_INT64: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_INT8: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_STRING: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_UINT16: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_UINT32: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_UINT64: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_UINT8: ConfigurationValueType
CONFIGURATION_VALUE_TYPE_UNDEFINED: ConfigurationValueType
DESCRIPTOR: _descriptor.FileDescriptor

class ConfigurationGetRequest(_message.Message):
    __slots__ = ["index", "metadata"]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    index: int
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., index: _Optional[int] = ...) -> None: ...

class ConfigurationGetResponse(_message.Message):
    __slots__ = ["value"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: ConfigurationValue
    def __init__(self, value: _Optional[_Union[ConfigurationValue, _Mapping]] = ...) -> None: ...

class ConfigurationListRequest(_message.Message):
    __slots__ = ["metadata"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.DeviceMetadata
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ...) -> None: ...

class ConfigurationListResponse(_message.Message):
    __slots__ = ["options"]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    options: _containers.RepeatedCompositeFieldContainer[ConfigurationOption]
    def __init__(self, options: _Optional[_Iterable[_Union[ConfigurationOption, _Mapping]]] = ...) -> None: ...

class ConfigurationOption(_message.Message):
    __slots__ = ["help", "index", "label", "type"]
    HELP_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    help: str
    index: int
    label: str
    type: ConfigurationValueType
    def __init__(self, index: _Optional[int] = ..., label: _Optional[str] = ..., help: _Optional[str] = ..., type: _Optional[_Union[ConfigurationValueType, str]] = ...) -> None: ...

class ConfigurationSetRequest(_message.Message):
    __slots__ = ["index", "metadata", "value"]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    index: int
    metadata: _metadata_pb2.DeviceMetadata
    value: ConfigurationValue
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., index: _Optional[int] = ..., value: _Optional[_Union[ConfigurationValue, _Mapping]] = ...) -> None: ...

class ConfigurationSetResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ConfigurationValue(_message.Message):
    __slots__ = ["scalar"]
    SCALAR_FIELD_NUMBER: _ClassVar[int]
    scalar: ConfigurationValueScalar
    def __init__(self, scalar: _Optional[_Union[ConfigurationValueScalar, _Mapping]] = ...) -> None: ...

class ConfigurationValueScalar(_message.Message):
    __slots__ = ["bool_value", "float32_value", "float64_value", "int16_value", "int32_value", "int64_value", "int8_value", "string_value", "uint16_value", "uint32_value", "uint64_value", "uint8_value"]
    BOOL_VALUE_FIELD_NUMBER: _ClassVar[int]
    FLOAT32_VALUE_FIELD_NUMBER: _ClassVar[int]
    FLOAT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT16_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT32_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT8_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT16_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT32_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT8_VALUE_FIELD_NUMBER: _ClassVar[int]
    bool_value: bool
    float32_value: float
    float64_value: float
    int16_value: int
    int32_value: int
    int64_value: int
    int8_value: int
    string_value: str
    uint16_value: int
    uint32_value: int
    uint64_value: int
    uint8_value: int
    def __init__(self, bool_value: bool = ..., uint8_value: _Optional[int] = ..., uint16_value: _Optional[int] = ..., uint32_value: _Optional[int] = ..., uint64_value: _Optional[int] = ..., int8_value: _Optional[int] = ..., int16_value: _Optional[int] = ..., int32_value: _Optional[int] = ..., int64_value: _Optional[int] = ..., float32_value: _Optional[float] = ..., float64_value: _Optional[float] = ..., string_value: _Optional[str] = ...) -> None: ...

class ConfigurationValueType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avemmio_client/status.proto\x12\x08vemmiopb\"\x14\n\x12StatusCheckRequest\"\x15\n\x13StatusCheckResponse\"5\n\x11StatusCheckReport\x12 \n\x06status\x18\x01 \x01(\x0b\x32\x10.vemmiopb.Status\"[\n\x06Status\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x02 \x01(\t\x12\x17\n\x0f\x66irmware_update\x18\x03 \x01(\x08\x12\x11\n\twifi_rssi\x18\x04 \x01(\x05\x32[\n\rStatusService\x12J\n\x0bStatusCheck\x12\x1c.vemmiopb.StatusCheckRequest\x1a\x1d.vemmiopb.StatusCheckResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _STATUSCHECKREQUEST._serialized_start=40
  _STATUSCHECKREQUEST._serialized_end=60
  _STATUSCHECKRESPONSE._serialized_start=62
  _STATUSCHECKRESPONSE._serialized_end=83
  _STATUSCHECKREPORT._serialized_start=85
  _STATUSCHECKREPORT._serialized_end=138
  _STATUS._serialized_start=140
  _STATUS._serialized_end=231
  _STATUSSERVICE._serialized_start=233
  _STATUSSERVICE._serialized_end=324
# @@protoc_insertion_point(module_scope)



from google.protobuf import duration_pb2 as _duration_pb2
from vemmio_client import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

COLOR_BLUE: ColorComponent
COLOR_COLD_WHITE: ColorComponent
COLOR_GREEN: ColorComponent
COLOR_RED: ColorComponent
COLOR_UNSPECIFIED: ColorComponent
COLOR_WARM_WHITE: ColorComponent
DESCRIPTOR: _descriptor.FileDescriptor

class ColorReport(_message.Message):
    __slots__ = ["values"]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedCompositeFieldContainer[ColorValue]
    def __init__(self, values: _Optional[_Iterable[_Union[ColorValue, _Mapping]]] = ...) -> None: ...

class ColorResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ColorSetRequest(_message.Message):
    __slots__ = ["duration", "metadata", "values"]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    duration: _duration_pb2.Duration
    metadata: _metadata_pb2.DeviceMetadata
    values: _containers.RepeatedCompositeFieldContainer[ColorValue]
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.DeviceMetadata, _Mapping]] = ..., values: _Optional[_Iterable[_Union[ColorValue, _Mapping]]] = ..., duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class ColorValue(_message.Message):
    __slots__ = ["component", "value"]
    COMPONENT_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    component: ColorComponent
    value: int
    def __init__(self, component: _Optional[_Union[ColorComponent, str]] = ..., value: _Optional[int] = ...) -> None: ...

class ColorComponent(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



import asyncio
import base64
import pprint
from collections.abc import Callable
from enum import Enum
from typing import Any, Self, Iterable

import aiohttp
import async_timeout
from aiohttp import WSMsgType

from .const import LOGGER
from .metadata_pb2 import DeviceMetadata
from .pubsub_pb2 import (
    CommandRequestData,
    CommandReplyData,
    CommandRequest,
    REQUEST_TYPE_DATA,
    CommandReply,
    REPLY_TYPE_ERROR,
)
from .reports_pb2 import GatewayReport
from .websocket_pb2 import WebsocketMessage

CONNECT_ERRORS = (
    aiohttp.ClientError,
    asyncio.TimeoutError,
    OSError,
)


class DeviceInfo:
    def __init__(self, mac, typ, revision):
        self.mac = mac
        self.type = typ
        self.revision = revision

    @classmethod
    def from_dict(cls, json: dict[str, Any]) -> Self:
        return cls(
            json["mac"],
            json["type"],
            json["revision"],
        )


class DeviceNode:
    def __init__(self, uuid: bytes, capabilities: Iterable[str]):
        self.uuid = uuid
        self.capabilities = capabilities

    @classmethod
    def from_dict(cls, json: dict[str, Any]) -> Self:
        return cls(
            base64.b64decode(json["UUID"]),
            json["Capabilities"],
        )


class DeviceConnectionError(Exception):
    pass


class Event(Enum):
    CONN_CLOSED = 1


class Client:
    message_handler: Callable[[GatewayReport], None]
    event_handler: Callable[[Event], None]

    def __init__(self, host: str, port: int, session: aiohttp.ClientSession):
        self.host = host
        self.port = port
        self.session = session
        self._calls: dict[int, Call] = {}
        self._call_id = 0

    async def get_info(self) -> DeviceInfo:
        try:
            async with self.session.get(
                    f"http://{self.host}:{self.port}/api/v1/settings/structure",
                    raise_for_status=True,
                    timeout=10,
            ) as resp:
                return DeviceInfo.from_dict(await resp.json())
        except CONNECT_ERRORS as err:
            raise DeviceConnectionError(err) from err

    async def get_nodes(self) -> Iterable[DeviceNode]:
        try:
            async with self.session.get(
                    f"http://{self.host}:{self.port}/api/v1/settings/nodes",
                    raise_for_status=True,
                    timeout=10,
            ) as resp:
                json = await resp.json()
                return [DeviceNode.from_dict(c) for c in json["Capabilities"]]
        except CONNECT_ERRORS as err:
            raise DeviceConnectionError(err) from err

    async def turn_on(self, device_id: bytes) -> None:
        data = CommandRequestData()
        data.SwitchOn.metadata.CopyFrom(metadata(device_id))
        await self._call("Switch/SwitchOn", data)

    async def turn_off(self, device_id: bytes) -> None:
        data = CommandRequestData()
        data.SwitchOff.metadata.CopyFrom(metadata(device_id))
        await self._call("Switch/SwitchOff", data)

    async def connect(self):
        LOGGER.debug("Trying to connect to device at %s", self.host)
        self._client = await self.session.ws_connect(
            f"http://{self.host}:{self.port}/rpc", autoping=False
        )
        self._rx_task = asyncio.create_task(self._rx_msgs())
        LOGGER.debug("Connected to %s", self.host)

    async def _rx_msgs(self) -> None:
        while not self._client.closed:
            msg = await self._client.receive()
            LOGGER.debug("Received msg (%s): %s", self.host, msg)
            LOGGER.debug("MSG type %s : %s", msg.type, msg.type == WSMsgType.CLOSED)
            if msg.type == WSMsgType.CLOSED:
                LOGGER.debug("MSG TYPE CLOSED")
                break
            m = WebsocketMessage()
            m.ParseFromString(msg.data)

            pp = pprint.PrettyPrinter(indent=4)
            LOGGER.debug("MSG: %s", pp.pformat(m))

            if not self._client.closed:
                if m.frame_id > 0:
                    if m.frame_id not in self._calls:
                        LOGGER.warning("Response for an unknown request id: %s", m.frame_id)
                        return
                    call = self._calls.pop(m.frame_id)
                    if not call.resolve.cancelled():
                        call.resolve.set_result(m.reply)
                else:
                    LOGGER.debug("Handle report")
                    if self.message_handler:
                        self.message_handler(m.gateway_report)

        LOGGER.debug("Websocket client connection from %s closed", self.host)

        for call_item in self._calls.values():
            if not call_item.resolve.done():
                call_item.resolve.set_exception(Exception())
        self._calls.clear()

        if not self._client.closed:
            await self._client.close()

        self._client = None
        self.event_handler(Event.CONN_CLOSED)

    async def close(self):
        if self._rx_task:
            self._rx_task.cancel()
        if self._client:
            await self._client.close()

    async def _call(self, method: str, data: CommandRequestData, timeout: int = 10) -> CommandReplyData:
        call = Call(self._next_id, method, data)
        self._calls[call.frame_id] = call
        try:
            async with async_timeout.timeout(timeout):
                await call.send_request(self)
                reply: CommandReply = await call.resolve
        except asyncio.TimeoutError as exc:
            call.resolve.cancel()
            await call.resolve
            raise exc
        except ConnectionResetError as exc:
            raise exc

        if reply.type == REPLY_TYPE_ERROR:
            raise Exception(reply.error.message)

        return reply.data

    @property
    def _next_id(self) -> int:
        self._call_id += 1
        return self._call_id

    async def send_bytes(self, data: bytes):
        if self._client is None:
            raise RuntimeError("Not connected")
        await self._client.send_bytes(data)


class Call:
    def __init__(self, frame_id, method: str, data: CommandRequestData) -> None:
        self.frame_id = frame_id
        self.method = method
        self.data = data
        self.resolve: asyncio.Future = asyncio.Future()

    async def send_request(self, client: Client):
        req = CommandRequest()
        req.method = self.method
        req.type = REQUEST_TYPE_DATA
        req.data.CopyFrom(self.data)
        msg = WebsocketMessage()
        msg.frame_id = self.frame_id
        msg.request.CopyFrom(req)
        await client.send_bytes(msg.SerializeToString())


def metadata(device_id: bytes) -> DeviceMetadata:
    meta = DeviceMetadata()
    meta.mqtt.device_id = device_id
    return meta



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
SMOKE_MAINTENANCE_DUST_IN_DEVICE: SmokeDetectorMaintenance
SMOKE_MAINTENANCE_PERIODIC_INSPECTION: SmokeDetectorMaintenance
SMOKE_MAINTENANCE_UNSPECIFIED: SmokeDetectorMaintenance
SMOKE_REPLACEMENT_EOL: SmokeDetectorReplacement
SMOKE_REPLACEMENT_UNSPECIFIED: SmokeDetectorReplacement
SMOKE_STATE_CLEAR: SmokeDetectorState
SMOKE_STATE_DETECTED: SmokeDetectorState
SMOKE_STATE_MAINTENANCE_REQUIRED: SmokeDetectorState
SMOKE_STATE_REPLACEMENT_REQUIRED: SmokeDetectorState
SMOKE_STATE_SILENCED: SmokeDetectorState
SMOKE_STATE_TEST: SmokeDetectorState
SMOKE_STATE_UNSPECIFIED: SmokeDetectorState

class SmokeReport(_message.Message):
    __slots__ = ["maintenance", "replacement", "state"]
    MAINTENANCE_FIELD_NUMBER: _ClassVar[int]
    REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    maintenance: SmokeDetectorMaintenance
    replacement: SmokeDetectorReplacement
    state: SmokeDetectorState
    def __init__(self, state: _Optional[_Union[SmokeDetectorState, str]] = ..., replacement: _Optional[_Union[SmokeDetectorReplacement, str]] = ..., maintenance: _Optional[_Union[SmokeDetectorMaintenance, str]] = ...) -> None: ...

class SmokeDetectorState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class SmokeDetectorReplacement(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class SmokeDetectorMaintenance(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/gate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18vemmio_client/gate.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"9\n\x0bGateRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x0e\n\x0cGateResponse\"0\n\nGateReport\x12\"\n\x05state\x18\x01 \x01(\x0e\x32\x13.vemmiopb.GateState*P\n\tGateState\x12\x10\n\x0cGATE_UNKNOWN\x10\x00\x12\x0f\n\x0bGATE_OPENED\x10\x01\x12\x0f\n\x0bGATE_CLOSED\x10\x02\x12\x0f\n\x0bGATE_CYCLED\x10\x03\x32\xc0\x01\n\x0bGateService\x12\x39\n\x08GateOpen\x12\x15.vemmiopb.GateRequest\x1a\x16.vemmiopb.GateResponse\x12:\n\tGateClose\x12\x15.vemmiopb.GateRequest\x1a\x16.vemmiopb.GateResponse\x12:\n\tGateCycle\x12\x15.vemmiopb.GateRequest\x1a\x16.vemmiopb.GateResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.gate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _GATESTATE._serialized_start=193
  _GATESTATE._serialized_end=273
  _GATEREQUEST._serialized_start=68
  _GATEREQUEST._serialized_end=125
  _GATERESPONSE._serialized_start=127
  _GATERESPONSE._serialized_end=141
  _GATEREPORT._serialized_start=143
  _GATEREPORT._serialized_end=191
  _GATESERVICE._serialized_start=276
  _GATESERVICE._serialized_end=468
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/ultraviolet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2
from vemmio_client import units_pb2 as vemmio__client_dot_units__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvemmio_client/ultraviolet.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\x1a\x19vemmio_client/units.proto\"C\n\x15UltravioletGetRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"E\n\x16UltravioletGetResponse\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\"@\n\x11UltravioletReport\x12\x1c\n\x04unit\x18\x01 \x01(\x0e\x32\x0e.vemmiopb.Unit\x12\r\n\x05value\x18\x02 \x01(\x01\x32i\n\x12UltravioletService\x12S\n\x0eUltravioletGet\x12\x1f.vemmiopb.UltravioletGetRequest\x1a .vemmiopb.UltravioletGetResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.ultraviolet_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ULTRAVIOLETGETREQUEST._serialized_start=102
  _ULTRAVIOLETGETREQUEST._serialized_end=169
  _ULTRAVIOLETGETRESPONSE._serialized_start=171
  _ULTRAVIOLETGETRESPONSE._serialized_end=240
  _ULTRAVIOLETREPORT._serialized_start=242
  _ULTRAVIOLETREPORT._serialized_end=306
  _ULTRAVIOLETSERVICE._serialized_start=308
  _ULTRAVIOLETSERVICE._serialized_end=413
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Status(_message.Message):
    __slots__ = ["firmware_update", "firmware_version", "mac", "wifi_rssi"]
    FIRMWARE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    MAC_FIELD_NUMBER: _ClassVar[int]
    WIFI_RSSI_FIELD_NUMBER: _ClassVar[int]
    firmware_update: bool
    firmware_version: str
    mac: str
    wifi_rssi: int
    def __init__(self, mac: _Optional[str] = ..., firmware_version: _Optional[str] = ..., firmware_update: bool = ..., wifi_rssi: _Optional[int] = ...) -> None: ...

class StatusCheckReport(_message.Message):
    __slots__ = ["status"]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: Status
    def __init__(self, status: _Optional[_Union[Status, _Mapping]] = ...) -> None: ...

class StatusCheckRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StatusCheckResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/siren.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/siren.proto\x12\x08vemmiopb\x1a\x1cvemmio_client/metadata.proto\"B\n\x14SirenGetTonesRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\";\n\x15SirenGetTonesResponse\x12\"\n\x05tones\x18\x01 \x03(\x0b\x32\x13.vemmiopb.SirenTone\"V\n\x14SirenPlayToneRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x12\n\ntone_index\x18\x02 \x01(\x05\"\x17\n\x15SirenPlayToneResponse\"I\n\x1bSirenPlayDefaultToneRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"\x1e\n\x1cSirenPlayDefaultToneResponse\"H\n\x1aSirenGetDefaultToneRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"@\n\x1bSirenGetDefaultToneResponse\x12!\n\x04tone\x18\x01 \x01(\x0b\x32\x13.vemmiopb.SirenTone\"\\\n\x1aSirenSetDefaultToneRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x12\n\ntone_index\x18\x02 \x01(\x05\"\x1d\n\x1bSirenSetDefaultToneResponse\"C\n\x15SirenGetVolumeRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\"(\n\x16SirenGetVolumeResponse\x12\x0e\n\x06volume\x18\x01 \x01(\x05\"S\n\x15SirenSetVolumeRequest\x12*\n\x08metadata\x18\x01 \x01(\x0b\x32\x18.vemmiopb.DeviceMetadata\x12\x0e\n\x06volume\x18\x02 \x01(\x05\"\x18\n\x16SirenSetVolumeResponse\")\n\tSirenTone\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\"Y\n\x0bSirenReport\x12*\n\x05state\x18\x01 \x01(\x0e\x32\x1b.vemmiopb.SirenReport.State\"\x1e\n\x05State\x12\t\n\x05\x43LEAR\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\"{\n\nToneReport\x12)\n\x05state\x18\x01 \x01(\x0e\x32\x1a.vemmiopb.ToneReport.State\x12\x12\n\ntone_index\x18\x02 \x01(\x05\".\n\x05State\x12\x0c\n\x08INACTIVE\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x02\"\x1e\n\x0cVolumeReport\x12\x0e\n\x06volume\x18\x01 \x01(\x05\x32\x84\x05\n\x05Siren\x12P\n\rSirenGetTones\x12\x1e.vemmiopb.SirenGetTonesRequest\x1a\x1f.vemmiopb.SirenGetTonesResponse\x12P\n\rSirenPlayTone\x12\x1e.vemmiopb.SirenPlayToneRequest\x1a\x1f.vemmiopb.SirenPlayToneResponse\x12\x65\n\x14SirenPlayDefaultTone\x12%.vemmiopb.SirenPlayDefaultToneRequest\x1a&.vemmiopb.SirenPlayDefaultToneResponse\x12\x62\n\x13SirenGetDefaultTone\x12$.vemmiopb.SirenGetDefaultToneRequest\x1a%.vemmiopb.SirenGetDefaultToneResponse\x12\x62\n\x13SirenSetDefaultTone\x12$.vemmiopb.SirenSetDefaultToneRequest\x1a%.vemmiopb.SirenSetDefaultToneResponse\x12S\n\x0eSirenGetVolume\x12\x1f.vemmiopb.SirenGetVolumeRequest\x1a .vemmiopb.SirenGetVolumeResponse\x12S\n\x0eSirenSetVolume\x12\x1f.vemmiopb.SirenSetVolumeRequest\x1a .vemmiopb.SirenSetVolumeResponseB=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.siren_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _SIRENGETTONESREQUEST._serialized_start=69
  _SIRENGETTONESREQUEST._serialized_end=135
  _SIRENGETTONESRESPONSE._serialized_start=137
  _SIRENGETTONESRESPONSE._serialized_end=196
  _SIRENPLAYTONEREQUEST._serialized_start=198
  _SIRENPLAYTONEREQUEST._serialized_end=284
  _SIRENPLAYTONERESPONSE._serialized_start=286
  _SIRENPLAYTONERESPONSE._serialized_end=309
  _SIRENPLAYDEFAULTTONEREQUEST._serialized_start=311
  _SIRENPLAYDEFAULTTONEREQUEST._serialized_end=384
  _SIRENPLAYDEFAULTTONERESPONSE._serialized_start=386
  _SIRENPLAYDEFAULTTONERESPONSE._serialized_end=416
  _SIRENGETDEFAULTTONEREQUEST._serialized_start=418
  _SIRENGETDEFAULTTONEREQUEST._serialized_end=490
  _SIRENGETDEFAULTTONERESPONSE._serialized_start=492
  _SIRENGETDEFAULTTONERESPONSE._serialized_end=556
  _SIRENSETDEFAULTTONEREQUEST._serialized_start=558
  _SIRENSETDEFAULTTONEREQUEST._serialized_end=650
  _SIRENSETDEFAULTTONERESPONSE._serialized_start=652
  _SIRENSETDEFAULTTONERESPONSE._serialized_end=681
  _SIRENGETVOLUMEREQUEST._serialized_start=683
  _SIRENGETVOLUMEREQUEST._serialized_end=750
  _SIRENGETVOLUMERESPONSE._serialized_start=752
  _SIRENGETVOLUMERESPONSE._serialized_end=792
  _SIRENSETVOLUMEREQUEST._serialized_start=794
  _SIRENSETVOLUMEREQUEST._serialized_end=877
  _SIRENSETVOLUMERESPONSE._serialized_start=879
  _SIRENSETVOLUMERESPONSE._serialized_end=903
  _SIRENTONE._serialized_start=905
  _SIRENTONE._serialized_end=946
  _SIRENREPORT._serialized_start=948
  _SIRENREPORT._serialized_end=1037
  _SIRENREPORT_STATE._serialized_start=1007
  _SIRENREPORT_STATE._serialized_end=1037
  _TONEREPORT._serialized_start=1039
  _TONEREPORT._serialized_end=1162
  _TONEREPORT_STATE._serialized_start=1116
  _TONEREPORT_STATE._serialized_end=1162
  _VOLUMEREPORT._serialized_start=1164
  _VOLUMEREPORT._serialized_end=1194
  _SIREN._serialized_start=1197
  _SIREN._serialized_end=1841
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vemmio_client/zwave.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from vemmio_client import devices_pb2 as vemmio__client_dot_devices__pb2
from vemmio_client import metadata_pb2 as vemmio__client_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vemmio_client/zwave.proto\x12\x08vemmiopb\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bvemmio_client/devices.proto\x1a\x1cvemmio_client/metadata.proto\"%\n\x13ZWaveIncludeRequest\x12\x0e\n\x06secure\x18\x01 \x01(\x08\"\xf6\x02\n\x12ZWaveIncludeStatus\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.vemmiopb.ZWaveIncludeStatus.DeviceFoundH\x00\x12\x39\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x0b\x32(.vemmiopb.ZWaveIncludeStatus.DeviceAddedH\x00\x12:\n\x05ready\x18\x03 \x01(\x0b\x32).vemmiopb.ZWaveIncludeStatus.IncludeReadyH\x00\x12@\n\x08progress\x18\x04 \x01(\x0b\x32,.vemmiopb.ZWaveIncludeStatus.IncludeProgressH\x00\x1a\r\n\x0b\x44\x65viceFound\x1a\x30\n\x0b\x44\x65viceAdded\x12!\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x10.vemmiopb.Device\x1a\x0e\n\x0cIncludeReady\x1a\x11\n\x0fIncludeProgressB\x08\n\x06status\"\x15\n\x13ZWaveExcludeRequest\"\x8e\x03\n\x12ZWaveExcludeStatus\x12=\n\x07removed\x18\x01 \x01(\x0b\x32*.vemmiopb.ZWaveExcludeStatus.DeviceRemovedH\x00\x12:\n\x05ready\x18\x02 \x01(\x0b\x32).vemmiopb.ZWaveExcludeStatus.ExcludeReadyH\x00\x12@\n\x08progress\x18\x03 \x01(\x0b\x32,.vemmiopb.ZWaveExcludeStatus.ExcludeProgressH\x00\x12@\n\tnot_found\x18\x04 \x01(\x0b\x32+.vemmiopb.ZWaveExcludeStatus.DeviceNotFoundH\x00\x1a:\n\rDeviceRemoved\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.vemmiopb.ZWaveMetadata\x1a\x0e\n\x0c\x45xcludeReady\x1a\x11\n\x0f\x45xcludeProgress\x1a\x10\n\x0e\x44\x65viceNotFoundB\x08\n\x06status\"\x13\n\x11ZWaveAbortRequest\"\x14\n\x12ZWaveAbortResponse\"O\n\x10ZWaveTestRequest\x12,\n\x07node_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x13\n\x11ZWaveTestResponse\"\\\n\x10ZWaveHealRequest\x12,\n\x07node_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x1a\n\x12init_return_routes\x18\x02 \x01(\x08\"\x13\n\x11ZWaveHealResponse\",\n\x19ZWaveReplaceFailedRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\"\x1c\n\x1aZWaveReplaceFailedResponse\"+\n\x18ZWaveRemoveFailedRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\"\x1b\n\x19ZWaveRemoveFailedResponse\"\x19\n\x17ZWaveHealthCheckRequest\"\xca\x01\n\x16ZWaveHealthCheckStatus\x12\x34\n\x07started\x18\x01 \x01(\x0b\x32!.vemmiopb.ZWaveHealthCheckStartedH\x00\x12\x36\n\x08progress\x18\x02 \x01(\x0b\x32\".vemmiopb.ZWaveHealthCheckProgressH\x00\x12\x38\n\tcompleted\x18\x03 \x01(\x0b\x32#.vemmiopb.ZWaveHealthCheckCompletedH\x00\x42\x08\n\x06status\"\x19\n\x17ZWaveHealthCheckStarted\"8\n\x18ZWaveHealthCheckProgress\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\r\n\x05total\x18\x02 \x01(\x05\"K\n\x19ZWaveHealthCheckCompleted\x12.\n\x05nodes\x18\x01 \x03(\x0b\x32\x1f.vemmiopb.ZWaveHealthStatusNode\"h\n\x15ZWaveHealthStatusNode\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12/\n\x08\x63\x61tegory\x18\x02 \x01(\x0e\x32\x1d.vemmiopb.ZWaveHealthCategory\x12\r\n\x05value\x18\x03 \x01(\x05\"\x13\n\x11ZWaveNodesRequest\"8\n\x12ZWaveNodesResponse\x12\"\n\x05nodes\x18\x01 \x03(\x0b\x32\x13.vemmiopb.ZWaveNode\"#\n\x10ZWaveNodeRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\"6\n\x11ZWaveNodeResponse\x12!\n\x04node\x18\x01 \x01(\x0b\x32\x13.vemmiopb.ZWaveNode\"\x14\n\x12ZWaveUpdateRequest\"\xde\x01\n\x11ZWaveUpdateStatus\x12?\n\x08topology\x18\x01 \x01(\x0b\x32+.vemmiopb.ZWaveNetworkTopologyUpdateStartedH\x00\x12<\n\x08neighbor\x18\x02 \x01(\x0b\x32(.vemmiopb.ZWaveNodeNeighborUpdateStartedH\x00\x12@\n\tnode_info\x18\x03 \x01(\x0b\x32+.vemmiopb.ZWaveNodeInformationUpdateStartedH\x00\x42\x08\n\x06status\"#\n!ZWaveNetworkTopologyUpdateStarted\" \n\x1eZWaveNodeNeighborUpdateStarted\"#\n!ZWaveNodeInformationUpdateStarted\")\n\x16ZWaveUpdateNodeRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\"\x19\n\x17ZWaveUpdateNodeResponse\"\x13\n\x11ZWaveResetRequest\"\x14\n\x12ZWaveResetResponse\"\xf4\x01\n\tZWaveNode\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x11\n\tvendor_id\x18\x02 \x01(\x05\x12\x14\n\x0cproduct_type\x18\x03 \x01(\x05\x12\x12\n\nproduct_id\x18\x04 \x01(\x05\x12*\n\tendpoints\x18\x05 \x03(\x0b\x32\x17.vemmiopb.ZWaveEndpoint\x12\x19\n\x11manufacturer_name\x18\x06 \x01(\t\x12\x14\n\x0cproduct_name\x18\x07 \x01(\t\x12\x11\n\tuser_name\x18\x08 \x01(\t\x12)\n\x06status\x18\t \x01(\x0e\x32\x19.vemmiopb.ZWaveNodeStatus\"{\n\rZWaveEndpoint\x12\r\n\x05\x65p_id\x18\x01 \x01(\x05\x12\x15\n\rgeneric_class\x18\x02 \x01(\x05\x12\x16\n\x0especific_class\x18\x03 \x01(\x05\x12,\n\ninterfaces\x18\x04 \x03(\x0b\x32\x18.vemmiopb.ZWaveInterface\"\x94\x01\n\x0eZWaveInterface\x12\x15\n\rcommand_class\x18\x01 \x01(\x05\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x14\n\x0creal_version\x18\x04 \x01(\x05\x12\r\n\x05label\x18\x05 \x01(\t\x12\x0c\n\x04help\x18\x06 \x01(\t\x12\'\n\x05items\x18\x07 \x03(\x0b\x32\x18.vemmiopb.ZWaveValueItem\".\n\x0eZWaveValueItem\x12\r\n\x05value\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\"\x19\n\x17ZWaveListEntriesRequest\"M\n\x18ZWaveListEntriesResponse\x12\x31\n\x07\x65ntries\x18\x01 \x03(\x0b\x32 .vemmiopb.ZWaveProvisioningEntry\"R\n\x14ZWaveAddEntryRequest\x12\x0b\n\x03\x64sk\x18\x01 \x01(\t\x12-\n\x04info\x18\x02 \x03(\x0b\x32\x1f.vemmiopb.ZWaveProvisioningInfo\"\x17\n\x15ZWaveAddEntryResponse\"&\n\x17ZWaveRemoveEntryRequest\x12\x0b\n\x03\x64sk\x18\x01 \x01(\t\"\x1a\n\x18ZWaveRemoveEntryResponse\"T\n\x16ZWaveProvisioningEntry\x12\x0b\n\x03\x64sk\x18\x01 \x01(\t\x12-\n\x04info\x18\x02 \x03(\x0b\x32\x1f.vemmiopb.ZWaveProvisioningInfo\"\x8f\x03\n\x15ZWaveProvisioningInfo\x12\x42\n\x0cproduct_type\x18\x01 \x01(\x0b\x32*.vemmiopb.ZWaveProvisioningInfoProductTypeH\x00\x12>\n\nproduct_id\x18\x02 \x01(\x0b\x32(.vemmiopb.ZWaveProvisioningInfoProductIDH\x00\x12\x1c\n\x12inclusion_interval\x18\x03 \x01(\x05H\x00\x12\x0e\n\x04uuid\x18\x04 \x01(\tH\x00\x12\x0e\n\x04name\x18\x05 \x01(\tH\x00\x12\x12\n\x08location\x18\x06 \x01(\tH\x00\x12\x1a\n\x10inclusion_status\x18\x07 \x01(\x05H\x00\x12\x16\n\x0cgranted_keys\x18\x08 \x01(\x05H\x00\x12\x1c\n\x12\x62ootstrapping_mode\x18\t \x01(\x05H\x00\x12\x46\n\x0enetwork_status\x18\n \x01(\x0b\x32,.vemmiopb.ZWaveProvisioningInfoNetworkStatusH\x00\x42\x06\n\x04info\"d\n ZWaveProvisioningInfoProductType\x12\x15\n\rgeneric_class\x18\x01 \x01(\x05\x12\x16\n\x0especific_class\x18\x02 \x01(\x05\x12\x11\n\ticon_type\x18\x03 \x01(\x05\"\xa1\x01\n\x1eZWaveProvisioningInfoProductID\x12\x17\n\x0fmanufacturer_id\x18\x01 \x01(\x05\x12\x14\n\x0cproduct_type\x18\x02 \x01(\x05\x12\x12\n\nproduct_id\x18\x03 \x01(\x05\x12\x1b\n\x13\x61pplication_version\x18\x04 \x01(\x05\x12\x1f\n\x17\x61pplication_sub_version\x18\x05 \x01(\x05\"E\n\"ZWaveProvisioningInfoNetworkStatus\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\"N\n\x1dZWaveNotificationItemsRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\r\n\x05\x65p_id\x18\x02 \x01(\x05\x12\r\n\x05index\x18\x03 \x01(\x05\"/\n\x1eZWaveNotificationItemsResponse\x12\r\n\x05items\x18\x01 \x03(\x05*\x95\x01\n\x13ZWaveHealthCategory\x12\x1c\n\x18ZWAVE_HEALTH_UNSPECIFIED\x10\x00\x12\x16\n\x12ZWAVE_HEALTH_GREEN\x10\x01\x12\x17\n\x13ZWAVE_HEALTH_YELLOW\x10\x02\x12\x14\n\x10ZWAVE_HEALTH_RED\x10\x03\x12\x19\n\x15ZWAVE_HEALTH_CRITICAL\x10\x04*r\n\x0fZWaveNodeStatus\x12\x1b\n\x17NODE_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11NODE_STATUS_ALIVE\x10\x01\x12\x14\n\x10NODE_STATUS_DOWN\x10\x02\x12\x15\n\x11NODE_STATUS_SLEEP\x10\x03\x32\x8d\x0b\n\x05ZWave\x12M\n\x0cZWaveInclude\x12\x1d.vemmiopb.ZWaveIncludeRequest\x1a\x1c.vemmiopb.ZWaveIncludeStatus0\x01\x12M\n\x0cZWaveExclude\x12\x1d.vemmiopb.ZWaveExcludeRequest\x1a\x1c.vemmiopb.ZWaveExcludeStatus0\x01\x12G\n\nZWaveAbort\x12\x1b.vemmiopb.ZWaveAbortRequest\x1a\x1c.vemmiopb.ZWaveAbortResponse\x12K\n\x0eZWaveReadNodes\x12\x1b.vemmiopb.ZWaveNodesRequest\x1a\x1c.vemmiopb.ZWaveNodesResponse\x12H\n\rZWaveReadNode\x12\x1a.vemmiopb.ZWaveNodeRequest\x1a\x1b.vemmiopb.ZWaveNodeResponse\x12J\n\x0bZWaveUpdate\x12\x1c.vemmiopb.ZWaveUpdateRequest\x1a\x1b.vemmiopb.ZWaveUpdateStatus0\x01\x12V\n\x0fZWaveUpdateNode\x12 .vemmiopb.ZWaveUpdateNodeRequest\x1a!.vemmiopb.ZWaveUpdateNodeResponse\x12G\n\nZWaveReset\x12\x1b.vemmiopb.ZWaveResetRequest\x1a\x1c.vemmiopb.ZWaveResetResponse\x12Y\n\x10ZWaveListEntries\x12!.vemmiopb.ZWaveListEntriesRequest\x1a\".vemmiopb.ZWaveListEntriesResponse\x12P\n\rZWaveAddEntry\x12\x1e.vemmiopb.ZWaveAddEntryRequest\x1a\x1f.vemmiopb.ZWaveAddEntryResponse\x12Y\n\x10ZWaveRemoveEntry\x12!.vemmiopb.ZWaveRemoveEntryRequest\x1a\".vemmiopb.ZWaveRemoveEntryResponse\x12k\n\x16ZWaveNotificationItems\x12\'.vemmiopb.ZWaveNotificationItemsRequest\x1a(.vemmiopb.ZWaveNotificationItemsResponse\x12\x44\n\tZWaveTest\x12\x1a.vemmiopb.ZWaveTestRequest\x1a\x1b.vemmiopb.ZWaveTestResponse\x12\x44\n\tZWaveHeal\x12\x1a.vemmiopb.ZWaveHealRequest\x1a\x1b.vemmiopb.ZWaveHealResponse\x12_\n\x12ZWaveReplaceFailed\x12#.vemmiopb.ZWaveReplaceFailedRequest\x1a$.vemmiopb.ZWaveReplaceFailedResponse\x12\\\n\x11ZWaveRemoveFailed\x12\".vemmiopb.ZWaveRemoveFailedRequest\x1a#.vemmiopb.ZWaveRemoveFailedResponse\x12Y\n\x10ZWaveHealthCheck\x12!.vemmiopb.ZWaveHealthCheckRequest\x1a .vemmiopb.ZWaveHealthCheckStatus0\x01\x42=\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\x01Z\n./vemmiopbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vemmio_client.zwave_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-com.vemmio.ha.integration.vemmio.rpc.vemmiopbP\001Z\n./vemmiopb'
  _ZWAVEHEALTHCATEGORY._serialized_start=4329
  _ZWAVEHEALTHCATEGORY._serialized_end=4478
  _ZWAVENODESTATUS._serialized_start=4480
  _ZWAVENODESTATUS._serialized_end=4594
  _ZWAVEINCLUDEREQUEST._serialized_start=130
  _ZWAVEINCLUDEREQUEST._serialized_end=167
  _ZWAVEINCLUDESTATUS._serialized_start=170
  _ZWAVEINCLUDESTATUS._serialized_end=544
  _ZWAVEINCLUDESTATUS_DEVICEFOUND._serialized_start=436
  _ZWAVEINCLUDESTATUS_DEVICEFOUND._serialized_end=449
  _ZWAVEINCLUDESTATUS_DEVICEADDED._serialized_start=451
  _ZWAVEINCLUDESTATUS_DEVICEADDED._serialized_end=499
  _ZWAVEINCLUDESTATUS_INCLUDEREADY._serialized_start=501
  _ZWAVEINCLUDESTATUS_INCLUDEREADY._serialized_end=515
  _ZWAVEINCLUDESTATUS_INCLUDEPROGRESS._serialized_start=517
  _ZWAVEINCLUDESTATUS_INCLUDEPROGRESS._serialized_end=534
  _ZWAVEEXCLUDEREQUEST._serialized_start=546
  _ZWAVEEXCLUDEREQUEST._serialized_end=567
  _ZWAVEEXCLUDESTATUS._serialized_start=570
  _ZWAVEEXCLUDESTATUS._serialized_end=968
  _ZWAVEEXCLUDESTATUS_DEVICEREMOVED._serialized_start=847
  _ZWAVEEXCLUDESTATUS_DEVICEREMOVED._serialized_end=905
  _ZWAVEEXCLUDESTATUS_EXCLUDEREADY._serialized_start=907
  _ZWAVEEXCLUDESTATUS_EXCLUDEREADY._serialized_end=921
  _ZWAVEEXCLUDESTATUS_EXCLUDEPROGRESS._serialized_start=923
  _ZWAVEEXCLUDESTATUS_EXCLUDEPROGRESS._serialized_end=940
  _ZWAVEEXCLUDESTATUS_DEVICENOTFOUND._serialized_start=942
  _ZWAVEEXCLUDESTATUS_DEVICENOTFOUND._serialized_end=958
  _ZWAVEABORTREQUEST._serialized_start=970
  _ZWAVEABORTREQUEST._serialized_end=989
  _ZWAVEABORTRESPONSE._serialized_start=991
  _ZWAVEABORTRESPONSE._serialized_end=1011
  _ZWAVETESTREQUEST._serialized_start=1013
  _ZWAVETESTREQUEST._serialized_end=1092
  _ZWAVETESTRESPONSE._serialized_start=1094
  _ZWAVETESTRESPONSE._serialized_end=1113
  _ZWAVEHEALREQUEST._serialized_start=1115
  _ZWAVEHEALREQUEST._serialized_end=1207
  _ZWAVEHEALRESPONSE._serialized_start=1209
  _ZWAVEHEALRESPONSE._serialized_end=1228
  _ZWAVEREPLACEFAILEDREQUEST._serialized_start=1230
  _ZWAVEREPLACEFAILEDREQUEST._serialized_end=1274
  _ZWAVEREPLACEFAILEDRESPONSE._serialized_start=1276
  _ZWAVEREPLACEFAILEDRESPONSE._serialized_end=1304
  _ZWAVEREMOVEFAILEDREQUEST._serialized_start=1306
  _ZWAVEREMOVEFAILEDREQUEST._serialized_end=1349
  _ZWAVEREMOVEFAILEDRESPONSE._serialized_start=1351
  _ZWAVEREMOVEFAILEDRESPONSE._serialized_end=1378
  _ZWAVEHEALTHCHECKREQUEST._serialized_start=1380
  _ZWAVEHEALTHCHECKREQUEST._serialized_end=1405
  _ZWAVEHEALTHCHECKSTATUS._serialized_start=1408
  _ZWAVEHEALTHCHECKSTATUS._serialized_end=1610
  _ZWAVEHEALTHCHECKSTARTED._serialized_start=1612
  _ZWAVEHEALTHCHECKSTARTED._serialized_end=1637
  _ZWAVEHEALTHCHECKPROGRESS._serialized_start=1639
  _ZWAVEHEALTHCHECKPROGRESS._serialized_end=1695
  _ZWAVEHEALTHCHECKCOMPLETED._serialized_start=1697
  _ZWAVEHEALTHCHECKCOMPLETED._serialized_end=1772
  _ZWAVEHEALTHSTATUSNODE._serialized_start=1774
  _ZWAVEHEALTHSTATUSNODE._serialized_end=1878
  _ZWAVENODESREQUEST._serialized_start=1880
  _ZWAVENODESREQUEST._serialized_end=1899
  _ZWAVENODESRESPONSE._serialized_start=1901
  _ZWAVENODESRESPONSE._serialized_end=1957
  _ZWAVENODEREQUEST._serialized_start=1959
  _ZWAVENODEREQUEST._serialized_end=1994
  _ZWAVENODERESPONSE._serialized_start=1996
  _ZWAVENODERESPONSE._serialized_end=2050
  _ZWAVEUPDATEREQUEST._serialized_start=2052
  _ZWAVEUPDATEREQUEST._serialized_end=2072
  _ZWAVEUPDATESTATUS._serialized_start=2075
  _ZWAVEUPDATESTATUS._serialized_end=2297
  _ZWAVENETWORKTOPOLOGYUPDATESTARTED._serialized_start=2299
  _ZWAVENETWORKTOPOLOGYUPDATESTARTED._serialized_end=2334
  _ZWAVENODENEIGHBORUPDATESTARTED._serialized_start=2336
  _ZWAVENODENEIGHBORUPDATESTARTED._serialized_end=2368
  _ZWAVENODEINFORMATIONUPDATESTARTED._serialized_start=2370
  _ZWAVENODEINFORMATIONUPDATESTARTED._serialized_end=2405
  _ZWAVEUPDATENODEREQUEST._serialized_start=2407
  _ZWAVEUPDATENODEREQUEST._serialized_end=2448
  _ZWAVEUPDATENODERESPONSE._serialized_start=2450
  _ZWAVEUPDATENODERESPONSE._serialized_end=2475
  _ZWAVERESETREQUEST._serialized_start=2477
  _ZWAVERESETREQUEST._serialized_end=2496
  _ZWAVERESETRESPONSE._serialized_start=2498
  _ZWAVERESETRESPONSE._serialized_end=2518
  _ZWAVENODE._serialized_start=2521
  _ZWAVENODE._serialized_end=2765
  _ZWAVEENDPOINT._serialized_start=2767
  _ZWAVEENDPOINT._serialized_end=2890
  _ZWAVEINTERFACE._serialized_start=2893
  _ZWAVEINTERFACE._serialized_end=3041
  _ZWAVEVALUEITEM._serialized_start=3043
  _ZWAVEVALUEITEM._serialized_end=3089
  _ZWAVELISTENTRIESREQUEST._serialized_start=3091
  _ZWAVELISTENTRIESREQUEST._serialized_end=3116
  _ZWAVELISTENTRIESRESPONSE._serialized_start=3118
  _ZWAVELISTENTRIESRESPONSE._serialized_end=3195
  _ZWAVEADDENTRYREQUEST._serialized_start=3197
  _ZWAVEADDENTRYREQUEST._serialized_end=3279
  _ZWAVEADDENTRYRESPONSE._serialized_start=3281
  _ZWAVEADDENTRYRESPONSE._serialized_end=3304
  _ZWAVEREMOVEENTRYREQUEST._serialized_start=3306
  _ZWAVEREMOVEENTRYREQUEST._serialized_end=3344
  _ZWAVEREMOVEENTRYRESPONSE._serialized_start=3346
  _ZWAVEREMOVEENTRYRESPONSE._serialized_end=3372
  _ZWAVEPROVISIONINGENTRY._serialized_start=3374
  _ZWAVEPROVISIONINGENTRY._serialized_end=3458
  _ZWAVEPROVISIONINGINFO._serialized_start=3461
  _ZWAVEPROVISIONINGINFO._serialized_end=3860
  _ZWAVEPROVISIONINGINFOPRODUCTTYPE._serialized_start=3862
  _ZWAVEPROVISIONINGINFOPRODUCTTYPE._serialized_end=3962
  _ZWAVEPROVISIONINGINFOPRODUCTID._serialized_start=3965
  _ZWAVEPROVISIONINGINFOPRODUCTID._serialized_end=4126
  _ZWAVEPROVISIONINGINFONETWORKSTATUS._serialized_start=4128
  _ZWAVEPROVISIONINGINFONETWORKSTATUS._serialized_end=4197
  _ZWAVENOTIFICATIONITEMSREQUEST._serialized_start=4199
  _ZWAVENOTIFICATIONITEMSREQUEST._serialized_end=4277
  _ZWAVENOTIFICATIONITEMSRESPONSE._serialized_start=4279
  _ZWAVENOTIFICATIONITEMSRESPONSE._serialized_end=4326
  _ZWAVE._serialized_start=4597
  _ZWAVE._serialized_end=6018
# @@protoc_insertion_point(module_scope)



from vemmio_client import units_pb2 as _units_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
X: AccelerometerAxis
Y: AccelerometerAxis
Z: AccelerometerAxis

class AccelerometerReport(_message.Message):
    __slots__ = ["axis", "unit", "value"]
    AXIS_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    axis: AccelerometerAxis
    unit: _units_pb2.Unit
    value: float
    def __init__(self, axis: _Optional[_Union[AccelerometerAxis, str]] = ..., unit: _Optional[_Union[_units_pb2.Unit, str]] = ..., value: _Optional[float] = ...) -> None: ...

class AccelerometerAxis(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
